# searchophile

Contains file search functionality, combining find, grep, and sed commands.

## Install Requirements

This package installs
[refind](https://pypi.org/project/refind/),
[greplica](https://pypi.org/project/greplica/), and
[sedeuce](https://pypi.org/project/sedeuce/).
This allows the package to be OS-independent.
